Default mapper implementation for basic SCIM group compliance.
Works with maps or structs that have standard field names:
:id,:external_id,:display_name:members:meta_created,:meta_last_modified
Default mapper implementation for basic SCIM group compliance.
Works with maps or structs that have standard field names:
:id, :external_id, :display_name:members:meta_created, :meta_last_modified