ExScim.Resources.Resource protocol (ex_scim v0.2.2)

Copy Markdown View Source

Protocol for SCIM resource operations.

Summary

Types

t()

All the types that implement this protocol.

Functions

Returns the external ID (provider-assigned) of the resource, or nil.

Returns the internal ID of the resource, or nil if not yet assigned.

Returns a new resource with the given ID set.

Types

t()

@type t() :: term()

All the types that implement this protocol.

Functions

get_external_id(resource)

Returns the external ID (provider-assigned) of the resource, or nil.

get_id(resource)

Returns the internal ID of the resource, or nil if not yet assigned.

set_id(resource, id)

Returns a new resource with the given ID set.