Default mapper implementation for basic SCIM compliance.
Works with maps or structs that have standard field names:
:id,:external_id,:user_name,:active:name,:display_name,:emails:meta_created,:meta_last_modified
Default mapper implementation for basic SCIM compliance.
Works with maps or structs that have standard field names:
:id, :external_id, :user_name, :active:name, :display_name, :emails:meta_created, :meta_last_modified